const fs = require('fs');
const hcaptcha = require('hcaptcha');
const fastify = require('fastify')();
const report = require('./report');

// you can ignore these if you're testing locally
const sitekey = process.env.HCAPTCHA_SITEKEY;
const secret = process.env.HCAPTCHA_SECRET;

const index = fs.readFileSync('index.html', 'utf-8');
const reportPage = fs.readFileSync('report.html', 'utf-8');

fastify.register(require('fastify-formbody'))

fastify.get('/', (req, res) => {
	return res.type('text/html').send(index);
});

fastify.get('/report', (req, res) => {
	if (sitekey) {
		return res.type('text/html')
				  .send(reportPage.replace('$HCAPTCHA', `<br><div class="h-captcha" data-sitekey="${sitekey}"></div>`));
	} else {
		return res.type('text/html').send(reportPage.replace('$HCAPTCHA', ''));
	}
});

fastify.post('/report', async (req, res) => {
	if (secret) {
		let captcha = await hcaptcha.verify(secret, req.body['h-captcha-response']);
		if (!captcha.success || typeof req.body.exploit !== 'string') {
			return res.send('Invalid captcha or exploit!');
		}
	}

	report(req.body.exploit);

	return res.send('Exploit has been reported.');
});

fastify.listen(8080, '0.0.0.0');